import { ethers } from 'ethers';
import debug from 'debug';
import type { ReadChannel, ReadWriteChannel } from '@cerc-io/ts-channel';
import { ChainService, ChainEvent } from './chainservice';
import { ChainTransaction } from '../../../protocols/interfaces';
import { Address } from '../../../types/types';
import { NitroAdjudicator } from './adjudicator/nitro-adjudicator';
interface EthChain {
    provider: ethers.providers.JsonRpcProvider;
    chainID(): Promise<bigint>;
}
export declare class EthChainService implements ChainService {
    private chain;
    private na;
    private naAddress;
    private consensusAppAddress;
    private virtualPaymentAppAddress;
    private txSigner;
    private out;
    private logger;
    private ctx;
    private cancel;
    constructor(chain: EthChain, na: NitroAdjudicator, naAddress: string, consensusAppAddress: string, virtualPaymentAppAddress: string, txSigner: ethers.Signer, out: ReadWriteChannel<ChainEvent>, logger: debug.Debugger, ctx: AbortController, cancel: () => void);
    static newEthChainService(chainUrl: string, chainPk: string, naAddress: Address, caAddress: Address, vpaAddress: Address, logDestination?: WritableStream): Promise<EthChainService>;
    private static _newEthChainService;
    private defaultTxOpts;
    sendTransaction(tx: ChainTransaction): Promise<void>;
    private fatalF;
    private dispatchChainEvents;
    private subscribeForLogs;
    private splitBlockRange;
    eventFeed(): ReadChannel<ChainEvent>;
    getConsensusAppAddress(): Address;
    getVirtualPaymentAppAddress(): Address;
    getChainId(): Promise<bigint>;
    close(): void;
}
export {};
