import type { ReadChannel, ReadWriteChannel } from '@cerc-io/ts-channel';
import { MessageService } from './messageservice/messageservice';
import { ChainService } from './chainservice/chainservice';
import { Store } from './store/store';
import { PolicyMaker } from './policy-maker';
import { MetricsApi } from './metrics';
import { VoucherManager } from '../../payments/voucher-manager';
import { Objective, ObjectiveRequest } from '../../protocols/interfaces';
import { ObjectiveId } from '../../protocols/messages';
import { Address } from '../../types/types';
import { Voucher } from '../../payments/vouchers';
import { LedgerChannelInfo, PaymentChannelInfo } from '../query/types';
import { Destination } from '../../types/destination';
export type PaymentRequest = {
    channelId: Destination;
    amount?: bigint;
};
export declare class EngineEvent {
    completedObjectives: Objective[];
    failedObjectives: ObjectiveId[];
    receivedVouchers: Voucher[];
    ledgerChannelUpdates: LedgerChannelInfo[];
    paymentChannelUpdates: PaymentChannelInfo[];
    isEmpty(): boolean;
    merge(other: EngineEvent): void;
}
export declare class Engine {
    objectiveRequestsFromAPI?: ReadWriteChannel<ObjectiveRequest>;
    paymentRequestsFromAPI?: ReadWriteChannel<PaymentRequest>;
    private fromChain?;
    private fromMsg?;
    private fromLedger?;
    private _toApi?;
    private stop?;
    private msg?;
    private chain?;
    private store?;
    private policymaker?;
    private logger;
    private metrics?;
    private vm?;
    static new(vm: VoucherManager, msg: MessageService, chain: ChainService, store: Store, logDestination: WritableStream | undefined, policymaker: PolicyMaker, metricsApi?: MetricsApi): Engine;
    get toApi(): ReadChannel<EngineEvent>;
    close(): void;
    run(): Promise<void>;
    private handleProposal;
    private handleMessage;
    private handleChainEvent;
    private handleObjectiveRequest;
    private handlePaymentRequest;
    private sendMessages;
    private executeSideEffects;
    private attemptProgress;
    private generateNotifications;
    private registerPaymentChannel;
    private spawnConsensusChannelIfDirectFundObjective;
    private getOrCreateObjective;
    private constructObjectiveFromMessage;
    getConsensusAppAddress(): Address;
    getVirtualPaymentAppAddress(): Address;
    private logMessage;
    private recordMessageMetrics;
    private checkError;
}
