import { P2PMessageService } from '../client/engine/messageservice/p2p-message-service/service';
import { Client } from '../client/client';
import { Store } from '../client/engine/store/store';
import { Metrics } from '../client/engine/metrics';
import { Exit } from '../channel/state/outcome/exit';
/**
 * setupClient sets up a client using the given args
 *
 * @param msgPort
 * @param pk
 * @param chainPk
 */
export declare function setupClient(messageService: P2PMessageService, store: Store, options: {
    chainPk: string;
    chainURL: string;
    contractAddresses: {
        [key: string]: string;
    };
}, metricsApi?: Metrics): Promise<Client>;
/**
 * Left pads a 20 byte address hex string with zeros until it is a 32 byte hex string
 * e.g.,
 * 0x9546E319878D2ca7a21b481F873681DF344E0Df8 becomes
 * 0x0000000000000000000000009546E319878D2ca7a21b481F873681DF344E0Df8
 *
 * @param address - 20 byte hex string
 * @returns 32 byte padded hex string
 */
export declare function convertAddressToBytes32(address: string): string;
/**
 * createOutcome creates a basic outcome for a channel
 *
 * @param asset - The asset to fund the channel with
 * @param alpha - The address of the first participant
 * @param beta - The address of the second participant
 * @param amount - The amount to allocate to each participant
 * @returns An outcome for a directly funded channel with 100 wei allocated to each participant
 */
export declare function createOutcome(asset: string, alpha: string, beta: string, amount: number): Exit;
export declare function subscribeVoucherLogs(client: Client): Promise<void>;
